@@ -21,7 +21,7 @@ import torch
 from torch.optim import Optimizer
 from torch.nn.modules.loss import _Loss
 from torch.nn.utils import clip_grad_norm_
-from torch.cuda.amp import GradScaler, autocast
+from torch.cuda.amp import GradScaler
 from torch.utils.data import DataLoader, Dataset
 
 from dstk.pytorch import (check_tensor, CallbackInterface, CallbackHandler,
@@ -365,7 +365,10 @@ class BaseEnvironnement(BaseEstimator):
             for key, value in data.items():
                 if key not in control.expected_key_to_device:
                     data[key] = value.to(control.device)
-        with autocast(enabled=control.mixed_type_gpu):
+        with torch.autocast(
+            device_type=control.device.type,
+            enabled=control.mixed_type_gpu
+        ):
             output = self.forward(**data)
             if control.target_checktensor:
                 target = check_tensor(data[control.target_field])
@@ -568,7 +571,10 @@ class BaseEnvironnement(BaseEstimator):
             Objet optimizer de PyTorch. Si non renseigné doit être implémenté 
             dans le modèle et dans la partie build. Utile si un paramètre de 
             l'optimizer doit faire partie des hyperparamètres. Sinon à 
-            renseigner ici pour alléger l'implémentation globale.
+            renseigner ici pour alléger l'implémentation globale. Cela peut
+            être un optimizer instancier à l'exétieur, pour celà test si
+            'param_groups' est un attribu qui existe. Si c'est le cas
+            'optimizer_kargs' ne sera pas pris en compte.
         optimizer_kargs: Dict[str, any]
             Paramètres pour l'optimizer, si optimizer inclue dans la 
             modélisation et l'argument optimizer est à None cet argument ne 
@@ -673,7 +679,13 @@ class BaseEnvironnement(BaseEstimator):
                     "classe du modèle. La priorité est accordé à celui en "
                     "entré du fit et à donc écrasé celui du modèle de base."
                 )
-            self.optimizer = optimizer(self.parameters(), **optimizer_kargs)
+            if hasattr(optimizer, 'param_groups'):
+                self.optimizer = optimizer
+            else:
+                self.optimizer = optimizer(
+                    self.parameters(),
+                    **optimizer_kargs
+                )
 
         list_callbacks = CallbackHandler(callbacks)
         list_callbacks.copy()
@@ -737,13 +749,21 @@ class BaseEnvironnement(BaseEstimator):
                         x.lower() == 'fitstate' or
                         x.lower() == 'fit_state'
                     ),
-                loss_fn.__code__.co_varnames
+                (
+                    loss_fn.__code__.co_varnames
+                    if isinstance(loss_fn, FunctionType)
+                    else loss_fn.__class__.forward.__code__.co_varnames
+                )
             )
         )
         state_in_loos_kargs = list(
             filter(
                 lambda x: x == 'kargs' or x == 'kwargs',
-                loss_fn.__code__.co_varnames
+                (
+                    loss_fn.__code__.co_varnames
+                    if isinstance(loss_fn, FunctionType)
+                    else loss_fn.__class__.forward.__code__.co_varnames
+                )
             )
         )
         if len(state_in_loss) == 1:
