@@ -1098,7 +1098,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                 pkl.dump(
                     self.scheduler.state_dict(),
                     open(
-                        f"{self.path_backup}/{state.id_process}_{state.n_iter}.lsc",
+                        f"{self.path_backup}/{state.id_process}_{state.n_iter}.lrs",
                         "wb"
                     )
                 )
@@ -1108,7 +1108,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                         filter(
                             lambda x: (
                                 x.startswith(state.id_process)
-                                and x.endswith('.lsc')
+                                and x.endswith('.lrs')
                             ),
                             os.listdir(f"{self.path_backup}/")
                         )
@@ -1134,7 +1134,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                     filter(
                         lambda x: (
                             x.startswith(state.id_process)
-                            and x.endswith('.lsc')
+                            and x.endswith('.lrs')
                         ),
                         os.listdir(f"{self.path_backup}/")
                     )
@@ -1158,7 +1158,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                     filter(
                         lambda x: (
                             x.startswith(state.id_process)
-                            and x.endswith('.lsc')
+                            and x.endswith('.lrs')
                         ),
                         os.listdir(f"{self.path_backup}/")
                     )
